@@ -2,7 +2,7 @@
 Date         : 2022-10-25 15:44:41
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-10-11 14:22:31
+LastEditTime : 2023-10-11 16:33:19
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\__init__.py
@@ -11,6 +11,6 @@ Copyright (c) 2022 by BDFD, All Rights Reserved.
 
 from execdata.templateproj import add_one, add_two
 from execdata.data_conversion import convint, convfloat
-from execdata.data_preprocess import filtered_value_list
+from execdata.data_preprocess import filtered_value_list, drop_columns
 from execdata.standardization import encode, sep, split, strat_split
 from execdata.model_evaluate import model_evaluate, algo_accuracy, result_comparision
